@@ -50,13 +50,6 @@ curs_bad_state_error (const char *funcname)
   scm_misc_error (funcname, "bad curses internal state", SCM_BOOL_F);
 }
 
-static void
-curs_param_or_bad_state_error (const char *funcname)
-{
-  scm_misc_error (funcname,  "invalid parameters or bad curses internal state",
-		  SCM_BOOL_F);
-}
-
 /* Assign the colors to color pair zero */
 SCM
 gucu_assume_default_colors (SCM fg, SCM bg)
@@ -504,10 +497,8 @@ gucu_derwin (SCM orig, SCM nlines, SCM ncols, SCM begin_y, SCM begin_x)
 SCM
 gucu_doupdate ()
 {
-  int ret = doupdate ();
+  doupdate ();
   /* doupdate probably only fails when the screen is NULL */
-  //if (ret == ERR)
-  //  curs_bad_state_error ("doupdate");
 
   return SCM_UNSPECIFIED;
 }
@@ -852,11 +843,21 @@ gucu_is_notimeout_p (SCM win)
   return scm_from_bool (is_notimeout (_scm_to_window (win)));
 }
 
+#if defined(HAVE_IS_PAD) || ! defined(NCURSES_OPAQUE)
 SCM
 gucu_is_pad_p (SCM win)
 {
-  return scm_from_bool (is_pad (_scm_to_window (win)));
+  WINDOW *c_pad;
+
+  c_pad = _scm_to_window (win);
+
+#ifdef HAVE_IS_PAD
+  return scm_from_bool (is_pad (c_pad));
+#else
+  return scm_from_bool (c_pad->_flags & _ISPAD);
+#endif
 }
+#endif
 
 SCM
 gucu_is_scrollok_p (SCM win)
@@ -864,11 +865,21 @@ gucu_is_scrollok_p (SCM win)
   return scm_from_bool (is_scrollok (_scm_to_window (win)));
 }
 
+#if defined(HAVE_IS_SUBWIN) || ! defined(NCURSES_OPAQUE)
 SCM
 gucu_is_subwin_p (SCM win)
 {
-  return scm_from_bool (is_subwin (_scm_to_window (win)));
+  WINDOW *c_subwin;
+
+  c_subwin = _scm_to_window (win);
+
+#ifdef HAVE_IS_SUBWIN
+  return scm_from_bool (is_subwin (c_subwin));
+#else
+  return scm_from_bool (c_subwin->_flags & _SUBWIN);
+#endif
 }
+#endif
 
 SCM
 gucu_is_syncok_p (SCM win)
@@ -2365,9 +2376,13 @@ gucu_init_function ()
   scm_c_define_gsubr ("%is-leaveok?", 1, 0, 0, gucu_is_leaveok_p);
   scm_c_define_gsubr ("%is-nodelay?", 1, 0, 0, gucu_is_nodelay_p);
   scm_c_define_gsubr ("%is-notimeout?", 1, 0, 0, gucu_is_notimeout_p);
+#if defined(HAVE_IS_PAD) || ! defined(NCURSES_OPAQUE)
   scm_c_define_gsubr ("%is-pad?", 1, 0, 0, gucu_is_pad_p);
+#endif
   scm_c_define_gsubr ("%is-scrollok?", 1, 0, 0, gucu_is_scrollok_p);
+#if defined(HAVE_IS_SUBWIN) || ! defined(NCURSES_OPAQUE)
   scm_c_define_gsubr ("%is-subwin?", 1, 0, 0, gucu_is_subwin_p);
+#endif
   scm_c_define_gsubr ("%is-syncok?", 1, 0, 0, gucu_is_syncok_p);
   scm_c_define_gsubr ("is-linetouched?", 2, 0, 0, gucu_is_linetouched_p);
   scm_c_define_gsubr ("is-wintouched?", 1, 0, 0, gucu_is_wintouched_p);
