@@ -28,6 +28,8 @@
   #:export (
 
             %filter
+            %is-pad-broken
+            %is-subwin-broken
             %scheme-char-from-c-char
             %scheme-char-from-c-wchar
             %scheme-char-to-c-char
@@ -1929,7 +1931,7 @@ tty driver queue will be flushed. #f disables this."
   "True if clearok is set, that is, if the next call to 'refresh'
 will clear the screen completely and redraw"
   (assert-window win)
-  (%is-clearok? win))
+  (%is-cleared? win))
 
 (define (is-idcok? win)
   "True if idcok is set, that is, if curses is allowed to use the hardware
@@ -1955,6 +1957,13 @@ this window."
   (assert-window win)
   (%is-keypad? win))
 
+(define (is-leaveok? win)
+  "True if leaveok is set, that is, if you don't care that the cursor gets
+returned to its true position after a refresh."
+  (assert-window win)
+  (%is-leaveok? win))
+
+
 (define (is-nodelay? win)
   "True if nodelay is set, that is, if 'getch' is a non-blocking call."
   (assert-window win)
@@ -1966,9 +1975,16 @@ this window."
   (%is-notimeout? win))
 
 (define (is-pad? win)
-  "True if the window is a pad."
+  "True if the window is a pad. Also true if we can't distinguish between
+pads and normal windows, which could be true if you're running old versions
+of curses that have been compiled to be opaque.  False otherwise.
+
+To see if this function can actually detect a pad, check the value of the
+%is-pad-broken constant."
   (assert-window win)
-  (%is-pad? win))
+  (if %is-pad-broken
+      #t
+      (%is-pad? win)))
 
 (define (is-scrollok? win)
   "True if scrollok is set.  That is, if attempting to move off the bottom
@@ -1977,9 +1993,17 @@ margin of the screen will cause the window to scroll."
   (%is-scrollok? win))
 
 (define (is-subwin? win)
-  "True if this window is a subwindow of another window."
+  "True if this window is a subwindow of another window.  Also true if
+the underlying ncurses library has no way of reporting if a window
+is a subwindow, which may be true for older versions of ncurses compiled
+to be opaque.  False otherwise.
+
+To see if this function actually works, chech the value of the
+%is-subwin-broken constant."
   (assert-window win)
-  (%is-subwin? win))
+  (if %is-subwin-broken
+      #t
+      (%is-subwin? win)))
 
 (define (is-syncok? win)
   "True if syncok is enabled, e.g, if every change to a window changes
@@ -2003,7 +2027,7 @@ sequences that are specific to the terminal."
   "Returns the character used to kill lines."
   (%killchar))
 
-(define (leaveokok! win bf)
+(define (leaveok! win bf)
   "If leaveok! is called with BF as #t, the cursor is allowed to be
 left wherever it happens to be, instead of taking the time to move it
 into its proper position.  This is a slight optimization for those
@@ -2527,9 +2551,5 @@ by the given window."
 ;; These functions may not exist depending on the
 ;; compile time options
 (if (defined? 'KEY_EVENT)    (export KEY_EVENT))
-(if (defined? 'grantpt)      (export grantpt))
 (if (defined? 'key-defined)  (export key-defined))
-(if (defined? 'ptsname)      (export ptsname))
 (if (defined? 'ptsraw)       (export ptsraw))
-(if (defined? 'ptsmakeraw)   (export ptsmakeraw))
-(if (defined? 'unlockpt)     (export unlockpt))
