@@ -23,7 +23,6 @@
 #include <config.h>
 
 #include <libguile.h>
-#include <libintl.h>
 
 #if HAVE_CURSES_H
 #include <curses.h>
@@ -43,13 +42,13 @@
 static void
 menu_posted_error (const char *funcname)
 {
-  scm_misc_error (funcname, gettext ("menu already posted"), SCM_BOOL_F);
+  scm_misc_error (funcname, "menu already posted", SCM_BOOL_F);
 }
 
 static void
 menu_not_connected_error (const char *funcname)
 {
-  scm_misc_error (funcname, gettext ("menu has no items"), SCM_BOOL_F);
+  scm_misc_error (funcname, "menu has no items", SCM_BOOL_F);
 }
 
 /* Set the foreground attribute of the menu */
